@@ -52,12 +52,12 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
@@ -133,12 +133,12 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIplus_Selector',
@@ -214,12 +214,12 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.STMBplus_Selector',
@@ -295,12 +295,12 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.aSTMBplus_Selector',
@@ -376,12 +376,12 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.sSTMBplus_Selector',
@@ -457,12 +457,12 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.pSTMB_Selector',
@@ -537,12 +537,12 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_STMB_Selector',
@@ -619,12 +619,12 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_aSTMB_Selector',
@@ -700,12 +700,12 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_sSTMB_Selector',
@@ -781,12 +781,12 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
             {
                 'type': 'PIP',
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.2'
+                'version': '2.0.4'
             },
             {
                 'type': 'PIP',
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.3'
+	            'version': '2.1.6'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIp_Selector',
@@ -813,8 +813,8 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
 
 
     def fit(self, *, timeout: float = None, iterations: int = None) -> None:
-        if self._fitted:
-            return CallResult(None)
+        #if self._fitted:
+        #    return CallResult(None)
 
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
